"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getCacheSize = getCacheSize;
exports.getHttpCacheSize = getHttpCacheSize;
exports.getImageCacheSize = getImageCacheSize;
exports.sizeNumToReadStr = sizeNumToReadStr;
exports.clearCache = clearCache;
exports.clearImageCache = exports.clearHttpCache = void 0;

var _reactNative = require("react-native");

const native = _reactNative.NativeModules.DMNHttpCache;
const clearHttpCache = native.clearHttpCache;
exports.clearHttpCache = clearHttpCache;
const clearImageCache = native.clearImageCache;
exports.clearImageCache = clearImageCache;

async function getCacheSize() {
  const arr = await Promise.all([getHttpCacheSize(), getImageCacheSize()]);
  console.log(arr.join(','));
  return arr.reduce((a, b) => a + b, 0);
}

async function getHttpCacheSize() {
  const size = await native.getHttpCacheSize();
  return size;
}

async function getImageCacheSize() {
  const size = await native.getImageCacheSize();
  return size;
}

function sizeNumToReadStr(size) {
  let str = '0 K';

  if (size >= 1024 * 1024 * 1024) {
    str = `${(size / 1024.0 / 1024.0 / 1024.0).toFixed(2)} G`;
  } else if (size >= 1024 * 1024) {
    str = `${(size / 1024.0 / 1024.0).toFixed(2)} M`;
  } else if (size >= 1024) {
    str = `${(size / 1024.0).toFixed(2)} K`;
  }

  return str;
}

async function clearCache() {
  await Promise.all([clearHttpCache(), clearImageCache()]);
}
//# sourceMappingURL=index.js.map